#!/usr/bin/python

# Grouchery
#
# Copyright (C) 2009-2012 Andrea Colangelo
# Copyright (C) 2009-2012 Andrea Gasparini
#
# Authors: Andrea Colangelo <warp10@ubuntu.com>
#          Andrea Gasparini <gaspa@yattaweb.it>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

from gi.repository import AppIndicator3 as appindicator
from gi.repository import Gtk
from gi.repository import GLib
from gi.repository import Notify
from random import seed, randrange

from .include import get_groucho_icon
from . import config
from . import gui


class Grouchery():
    def __init__(self):
        self.conf = config.Config()

        if self.conf.get_options_autofortune():
            self.show_fortune()

        if self.conf.get_options_timed_fortune():
            GLib.timeout_add_seconds(self.conf.get_options_time() * 60,
                                     self.show_fortune)

        self.load_indicator()

    def load_indicator(self):
        self.ind = appindicator.Indicator.new("grouchery",
                        get_groucho_icon(),
                        appindicator.IndicatorCategory.APPLICATION_STATUS)
        self.ind.set_status(appindicator.IndicatorStatus.ACTIVE)

        menu = Gtk.Menu()

        buf = "Show fortune"
        menu_items = Gtk.MenuItem(buf)
        menu.append(menu_items)
        menu_items.connect("activate", self.show_fortune, buf)
        menu_items.show()

        menu_items = Gtk.SeparatorMenuItem()
        menu.append(menu_items)
        menu_items.show()

        buf = "Configure Grouchery"
        menu_items = Gtk.MenuItem(buf)
        menu.append(menu_items)
        menu_items.connect("activate", self.show_gui, buf)
        menu_items.show()

        buf = "Quit"
        menu_items = Gtk.MenuItem(buf)
        menu.append(menu_items)
        menu_items.connect("activate", self.quit, buf)
        menu_items.show()
        menu.show()

        self.ind.set_menu(menu)

    def show_gui(self, *args):
        g = gui.Gui(self.conf)
        g.show_all()

    def show_fortune(self, *args):
        header = "Grouchery says:"

        if 'icon-static' in Notify.get_server_caps():
            icon = get_groucho_icon()
        else:
            icon = None

        fortune = self.get_fortune()

        Notify.init('Grouchery')
        cookie = Notify.Notification.new(header, fortune, icon)
        if not cookie.show():
            return False
        return True

    def get_fortune(self):
        seed()
        n = randrange(0, len(self.conf.get_fortunes_list()))
        return self.conf.get_fortune(n)

    def main(self):
        Gtk.main()

    def quit(self, *args):
        Gtk.main_quit()
