#!/usr/bin/python

# Grouchery
#
# Copyright (C) 2009-2012 Andrea Colangelo
# Copyright (C) 2009-2012 Andrea Gasparini
#
# Authors: Andrea Colangelo <warp10@ubuntu.com>
#          Andrea Gasparini <gaspa@yattaweb.it>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

import json
import os

from .include import LIST_FILES, get_configuration_path, get_fortune_path, \
                     exists_configuration_path, exists_fortune_path


class Config():
    def __init__(self):
        self.conffile = get_configuration_path()
        self.fortunesfile = get_fortune_path()
        if not exists_configuration_path():
            self.write_first_conffile()
        if not exists_fortune_path():
            self.write_first_fortunesfile()
        self.conf = self.read_file(self.conffile)
        self.fort = self.read_file(self.fortunesfile)

    def assure_dir(self, filename):
        dirname = os.path.dirname(filename)
        if not os.path.exists(dirname):
            os.makedirs(dirname)

    def write_first_conffile(self):
        print("Writing default configuration file: " + self.conffile)
        self.conf = {"autofortune": True, "timed_fortune": True, "time": 60,
                     "autostart": False}
        self.assure_dir(self.conffile)
        self.save_file(self.conffile, self.conf)

    def write_first_fortunesfile(self):
        print("Writing default fortunes file: " + self.fortunesfile)
        fortunes = []
        for list_file in LIST_FILES:
            for fortune in self.load_list_file(list_file):
                fortunes.append(fortune)
        self.fort = list(set(fortunes))  # delete duplicates
        self.assure_dir(self.fortunesfile)
        self.save_file(self.fortunesfile, self.fort)

    def load_list_file(self, list_file):
        with open(list_file, 'r') as listfile:
            return listfile.read().splitlines()

    def save_file(self, filename, data):
        with open(filename, 'w') as f:
            j = json.dumps(data)
            json.dump(j, f)

    def save_all(self):
        self.save_file(self.conffile, self.conf)
        self.save_file(self.fortunesfile, self.fort)

    def read_file(self, filename):
        with open(filename, 'r') as f:
            j = json.load(f)
            return json.loads(j)

    def get_fortunes_list(self):
        return self.fort

    def set_fortunes_list(self, fortunes_list):
        self.fort = fortunes_list

    def get_fortune(self, item):
        return self.fort[item]

    def get_options_autofortune(self):
        return self.conf["autofortune"]

    def set_options_autofortune(self, option):
        self.conf["autofortune"] = option

    def get_options_timed_fortune(self):
        return self.conf["timed_fortune"]

    def set_options_timed_fortune(self, option):
        self.conf["timed_fortune"] = option

    def get_options_time(self):
        return self.conf["time"]

    def set_options_time(self, option):
        self.conf["time"] = option

    def get_options_autostart(self):
        return self.conf["autostart"]

    def set_options_autostart(self, option):
        self.conf["autostart"] = option
