#!/usr/bin/python

# Grouchery
#
# Copyright (C) 2009-2012 Andrea Colangelo
# Copyright (C) 2009-2012 Andrea Gasparini
#
# Authors: Andrea Colangelo <warp10@ubuntu.com>
#          Andrea Gasparini <gaspa@yattaweb.it>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

from gi.repository import Gtk
from .include import get_groucho_icon


class Gui(Gtk.Dialog):
    def __init__(self, conf):
        self.conf = conf
        Gtk.Dialog.__init__(self, title="Grouchery Configuration")
        self.set_default_size(700, 400)
        self.set_icon_from_file(get_groucho_icon())
        self.connect("delete-event", self.quit)

        #Cancel Button
        self.button_cancel = self.add_button(Gtk.STOCK_CANCEL,
                                             Gtk.ResponseType.CANCEL)
        self.button_cancel.connect("clicked", self.quit)

        #Save Button
        self.button_ok = self.add_button(Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
        self.button_ok.connect("clicked", self.save_config)

        #Main Box
        self.box_main = self.get_content_area()

        #Fortunes Vbox
        self.box_fortunes = Gtk.Box(orientation=Gtk.Orientation.VERTICAL,
                                    spacing=0)

        #Options Vbox
        self.box_options = Gtk.Box(orientation=Gtk.Orientation.VERTICAL,
                                   spacing=0)

        #Notebook
        self.notebook = Gtk.Notebook()
        self.label_fortunes = Gtk.Label("Fortunes")
        self.notebook.append_page(self.box_fortunes, self.label_fortunes)
        self.label_options = Gtk.Label("Options")
        self.notebook.append_page(self.box_options, self.label_options)
        self.box_main.pack_start(self.notebook, True, True, 0)

        #ScrolledWindow to host fortunes list (Lists Vbox)
        self.scrolled_window = Gtk.ScrolledWindow()
        self.scrolled_window.set_border_width(10)
        self.box_fortunes.pack_start(self.scrolled_window, True, True, 0)

        #Fortunes list (Lists Vbox)
        self.store = Gtk.ListStore(str)
        self.liststore_loader(self.conf.get_fortunes_list())
        self.treeview = Gtk.TreeView(self.store)
        self.selection = self.treeview.get_selection()
        self.selection.connect("changed", self.on_tree_selection_changed)
        self.renderer = Gtk.CellRendererText()
        self.renderer.set_property("editable", True)
        self.renderer.connect("edited", self.edit_fortune)
        self.column = Gtk.TreeViewColumn("Available fortunes:", self.renderer,
                                         text=0)
        self.treeview.append_column(self.column)
        self.scrolled_window.add_with_viewport(self.treeview)

        #Hbox to host lists buttons (Lists Vbox)
        self.box_fortunes_buttons = Gtk.Box(
                             orientation=Gtk.Orientation.HORIZONTAL, spacing=0)
        self.box_fortunes.pack_start(self.box_fortunes_buttons,
                                     False, False, 0)

        #Remove Button (Lists Vbox, Hbox)
        self.button_remove = Gtk.Button("Remove")
        self.button_remove.connect("clicked", self.remove_fortune)
        self.box_fortunes_buttons.pack_start(self.button_remove, True, True, 0)

        #Add Button (Lists Vbox, Hbox)
        self.button_add = Gtk.Button("Add")
        self.button_add.connect("clicked", self.add_fortune)
        self.box_fortunes_buttons.pack_start(self.button_add, True, True, 0)

        #Load Button (Lists Vbox, Hbox)
        self.button_load = Gtk.Button("Load from file")
        self.button_load.connect("clicked", self.load_list)
        self.box_fortunes_buttons.pack_start(self.button_load, True, True, 0)

        #Hbox to host autofortune settings (Options Vbox)
        self.box_autofortune = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL,
                                       spacing=5)
        self.box_options.pack_start(self.box_autofortune, False, False, 0)

        #Autofortune Switch + Label (Options Vbox, Hbox)
        self.switch_autofortune = Gtk.Switch()
        self.switch_autofortune.set_active(self.conf.get_options_autofortune())
        self.box_autofortune.pack_start(self.switch_autofortune,
                                        False, False, 0)
        self.label_autofortune = Gtk.Label("Show a fortune cookie at startup")
        self.box_autofortune.pack_start(self.label_autofortune,
                                        False, False, 0)

        #Hbox to host timed fortune settings (Options Vbox)
        self.box_options_time = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL,
                                        spacing=5)
        self.box_options.pack_start(self.box_options_time, False, False, 0)

        #Timed fortune Switch (Options Vbox, Hbox)
        self.switch_timed_fortune = Gtk.Switch()
        self.switch_timed_fortune.set_active(self.conf.get_options_timed_fortune())
        self.box_options_time.pack_start(self.switch_timed_fortune,
                                         False, False, 0)

        #Timed fortune Label + Spinbutton + Label (Options Vbox, Hbox)
        self.label_time = Gtk.Label("Show a fortune cookie every: ")
        self.box_options_time.pack_start(self.label_time, False, False, 0)
        self.spinbutton_time = Gtk.SpinButton()
        adjustment = Gtk.Adjustment(30, 1, 360, 1, 10, 0)
        self.spinbutton_time.set_adjustment(adjustment)
        self.spinbutton_time.set_value(self.conf.get_options_time())
        self.box_options_time.pack_start(self.spinbutton_time, False, False, 0)
        self.label_time = Gtk.Label("minutes")
        self.box_options_time.pack_start(self.label_time, False, False, 0)

        #Hbox to host autostart settings (Options Vbox)
        self.box_autostart = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL,
                                     spacing=5)
        self.box_options.pack_start(self.box_autostart, False, False, 0)

        #Autosart Switch + Label (Options Vbox, Hbox)
        self.switch_autostart = Gtk.Switch()
        self.switch_autostart.set_active(self.conf.get_options_autostart())
        self.box_autostart.pack_start(self.switch_autostart, False, False, 0)
        self.label_autostart = Gtk.Label("Autostart Grouchery")
        self.box_autostart.pack_start(self.label_autostart, False, False, 0)

    def liststore_loader(self, fortunes_list):
        for fortune in fortunes_list:
            self.store.append([fortune])

    def on_tree_selection_changed(self, selection):
        self.model, self.treeiter = selection.get_selected()

    def remove_fortune(self, *args):
        self.store.remove(self.treeiter)

    def add_fortune(self, *args):
        self.store.prepend()
        self.treeview.set_cursor(Gtk.TreePath("0"), self.column,
                                 start_editing=True)

    def load_list(self, *args):
        fc = Gtk.FileChooserDialog("Choose a fortunes list file:",
                          parent=None,
                          action=Gtk.FileChooserAction.OPEN,
                          buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                    Gtk.STOCK_SAVE, Gtk.ResponseType.OK))
        if fc.run() == Gtk.ResponseType.OK:
            self.liststore_loader(self.conf.load_list_file(fc.get_filename()))
        fc.destroy()

    def edit_fortune(self, widget, line_number, new_fortune):
        if new_fortune:
            self.store.set_value(self.treeiter, 0, new_fortune)
        else:
            self.remove_fortune()

    def quit(self, *args):
        self.destroy()

    def save_config(self, *args):
        new_fortunes_list = []
        for i in self.store:
            new_fortunes_list.append(i[0])
        self.conf.set_fortunes_list(new_fortunes_list)

        self.conf.set_options_autofortune(self.switch_autofortune.get_active())
        self.conf.set_options_timed_fortune(self.switch_timed_fortune.get_active())
        self.conf.set_options_time(self.spinbutton_time.get_value_as_int())
        self.conf.set_options_autostart(self.switch_autostart.get_active())

        self.conf.save_all()

        self.quit()
