#!/usr/bin/python

# Grouchery
#
# Copyright (C) 2009-2012 Andrea Colangelo
# Copyright (C) 2009-2012 Andrea Gasparini
#
# Authors: Andrea Colangelo <warp10@ubuntu.com>
#          Andrea Gasparini <gaspa@yattaweb.it>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

import sys

from os.path import join, exists, isdir, dirname
from os import getcwd, listdir

from xdg.IconTheme import getIconPath
from xdg.BaseDirectory import save_config_path

__version = 0.1

lists_dir = ("lists", "/usr/share/grouchery/", "/usr/local/share/grouchery")

# needed resources:
GROUCHO_ICON = "files/groucho.png"
CONF_FILE = "files/grouchery.conf"
FORTUNE_FILE = 'files/grouchery.lists'
LIST_FILES = []


# get the path of the grouchery script
def get_running_path():
    return join(getcwd(), dirname(sys.argv[0]))


# guess if we're installed checking is the running directory contains
# the Grouchery module itself
def is_installed():
    path = get_running_path()
    return not isdir(join(path, 'Grouchery'))


# get the path of the groucho icon, returns "" if not found.
def get_groucho_icon():
    abspath = join(get_running_path(), GROUCHO_ICON)
    if is_installed():
        return getIconPath('grouchery', 48)
    elif exists(abspath):
        return abspath
    print("Warning: Icon file not found.")
    return ""


# get the path which should match the configuration file, cohoerently with
# the install status.
def get_configuration_path():
    if is_installed():
        return join(save_config_path('grouchery'), 'grouchery.conf')
    else:
        if exists(CONF_FILE):
            return CONF_FILE
        abspath = join(get_running_path(), CONF_FILE)
        return abspath


def exists_configuration_path():
    return exists(get_configuration_path())


# get the path for the fortune file, cohoerently with the install status
def get_fortune_path():
    if is_installed():
        return join(save_config_path('grouchery'), 'grouchery.list')
    else:
        if exists(FORTUNE_FILE):
            return FORTUNE_FILE
        abspath = join(get_running_path(), FORTUNE_FILE)
        return abspath


def exists_fortune_path():
    return exists(get_fortune_path())


def get_first_existing_dir(dirlist):
    for i in dirlist:
        if exists(i):
            return i

real_lists_dir = get_first_existing_dir(lists_dir)
for f in listdir(real_lists_dir):
    LIST_FILES.append(join(real_lists_dir, f))
